import 'package:dghub_bottombar/src/model/bottombar_config.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import '../../tools/tools.dart';

class Material3BottomBar extends StatefulWidget {
  final BottomBarConfig config;
  const Material3BottomBar({super.key, required this.config});

  @override
  State<Material3BottomBar> createState() => _Material3BottomBarState();
}

class _Material3BottomBarState extends State<Material3BottomBar>
    with SingleTickerProviderStateMixin {
  int currentIndex = 0;
  @override
  void initState() {
    super.initState();
  }

  double iconSize(BuildContext context) {
    if (Tools.isDesktop(context)) {
      return ScreenUtil().setHeight(25);
    } else {
      return ScreenUtil().setHeight(25);
    }
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      behavior: HitTestBehavior.opaque,
      onTap: widget.config.onTap,
      child: IgnorePointer(
          ignoring: widget.config.onTap == null ? false : true,
          child: NavigationBarTheme(
            data: NavigationBarThemeData(
              iconTheme: MaterialStateProperty.resolveWith<IconThemeData>(
                (Set<MaterialState> states) => IconThemeData(
                  color: states.contains(MaterialState.selected)
                      ? Tools.isDarkTheme(context)
                          ? widget.config.selectedIconColorDarkTheme
                          : widget.config.selectedIconColor
                      : Tools.isDarkTheme(context)
                          ? widget.config.unSelectedIconColorDarkTheme
                          : widget.config.unSelectedIconColor,
                ),
              ),
              labelTextStyle: MaterialStateProperty.resolveWith<TextStyle>(
                (Set<MaterialState> states) =>
                    states.contains(MaterialState.selected)
                        ? TextStyle(
                            color: Tools.isDarkTheme(context)
                                ? widget.config.selectedLabelColorDarkTheme
                                : widget.config.selectedLabelColor)
                        : TextStyle(
                            color: Tools.isDarkTheme(context)
                                ? widget.config.unSelectedLabelColorDarkTheme
                                : widget.config.unSelectedLabelColor),
              ),
            ),
            child: NavigationBar(
                indicatorColor: Tools.isDarkTheme(context)
                    ? widget.config.cardColorDarkTheme
                    : widget.config.cardColor,
                //  height: widget.config.height ?? 70,
                elevation: 0,
                backgroundColor: Tools.isDarkTheme(context)
                    ? widget.config.backgroundColorDarkTheme
                    : widget.config.backgroundColor,
                destinations: widget.config.items
                    .map((data) => NavigationDestination(
                        label: data.label,
                        icon: Icon(data.unSelectedIcon),
                        selectedIcon: Icon(data.selectedIcon)))
                    .toList(),
                selectedIndex: currentIndex,
                onDestinationSelected: (index) {
                  currentIndex = index;
                  setState(() {});
                  widget.config.result(index);
                }),
          )),
    );
  }
}
